pyxmpp.jabber.disco.DiscoCacheFetcherBase

Package pyxmpp :: Package jabber :: Module disco :: Class DiscoCacheFetcherBase |
[hide private]

# Class DiscoCacheFetcherBase

source code

    cache.CacheFetcher --+
                         |
                        DiscoCacheFetcherBase

Base class for disco cache fetchers.

Instance Methods | [hide private]
fetch(self) Initialize the Service Discovery process. | source code
__response(self, stanza) Handle successful disco response. | source code
__error(self, stanza) Handle disco error response. | source code
__timeout(self, stanza) Handle disco timeout. | source code
Inherited from `cache.CacheFetcher`: `__init__`, `error`, `got_it`, `timeout` Inherited from `cache.CacheFetcher` (private): `_deactivate`, `_deactivated`, `_try_backup_item`

Class Variables | [hide private]
pyxmpp.stream.Stream | stream = `None` stream used by the fetcher.
`classobj` | disco_class = `None` disco class to be used (DiscoInfo or DiscoItems).

Instance Variables | [hide private]
Inherited from `cache.CacheFetcher`: `active`, `address`, `cache`, `timeout_time`

Method Details | [hide private]

### fetch(self) | source code
Initialize the Service Discovery process. Overrides: cache.CacheFetcher.fetch

### __response(self, stanza) | source code
Handle successful disco response. Parameters: `stanza` (pyxmpp.stanza.Stanza) - the stanza received.

### __error(self, stanza) | source code
Handle disco error response. Parameters: `stanza` (pyxmpp.stanza.Stanza) - the stanza received.